@@ -21,7 +21,8 @@ import facades.files_facade as file
 import facades.directory_facade as dirs
 import facades.list_utils_facade as arr
 import facades.dict_utils_facade as dic
-import facades.rand_utils_facade as rand
+import utils.random_utils as rand
+# import facades.rand_utils_facade as rand
 import facades.string_facade as string
 import facades.types_facade as types
 
