@@ -16,10 +16,7 @@
     `method_name`: random
 '''
 
-
-from utils.string_generation import text,phone,email,url,abstract_name,rand
-
-
+from utils.random_utils import text,phone,email,url,abstract_name,rand
 
 
 
