@@ -51,6 +51,8 @@ PILLOW_SUPPORTED_IMAGE_EXTENSIONS = ["bmp","dds","dib","eps","gif","icns","ico",
 GET_DATA_INCLUDE_DEFAULT_VALUE = ['file_name', 'extension', 'name_no_ext', 'dir_path', 'access_time', 'modified_time', 'created_time', 'size']
 
 
+from utils.parse_utils import array_in_string
+
 
 
 
@@ -1320,12 +1322,12 @@ def get_files(search_path=False, **kwargs):
                     # print(f"file_data['extension']: {file_data['extension']}")
                     if len(exclude) > 0:
                         # print(f"filtering excludes")
-                        if utils.parse_utils.array_in_string(exclude, file_data['file_path']) is True:
+                        if array_in_string(exclude, file_data['file_path']) is True:
                             continue
 
                     if len(include) > 0:
                         # print(f"filtering includes")
-                        if utils.parse_utils.array_in_string(include, file_data['file_path']) is False:
+                        if array_in_string(include, file_data['file_path']) is False:
                             continue
 
                     if len(extension_array) > 0:
@@ -1515,11 +1517,11 @@ def get_files_ftp(search_path=False, **kwargs):
                     # ignore = False
                     # print(f"file_data['extension']: {file_data['extension']}")
                     if len(exclude) > 0:
-                        if utils.parse_utils.array_in_string(exclude, file_data['file_path']) is True:
+                        if array_in_string(exclude, file_data['file_path']) is True:
                             continue
 
                     if len(include) > 0:
-                        if utils.parse_utils.array_in_string(include, file_data['file_path']) is False:
+                        if array_in_string(include, file_data['file_path']) is False:
                             continue
 
                     if len(extension_array) > 0:
@@ -1621,11 +1623,11 @@ class GetFilesThreaded:
             # ignore = False
             # print(f"file_data['extension']: {file_data['extension']}")
             if len(self.exclude) > 0:
-                if utils.parse_utils.array_in_string(self.exclude, file_data['file_path']) is True:
+                if array_in_string(self.exclude, file_data['file_path']) is True:
                     return
 
             if len(self.include) > 0:
-                if utils.parse_utils.array_in_string(self.include, file_data['file_path']) is False:
+                if array_in_string(self.include, file_data['file_path']) is False:
                     return
 
             if len(self.extension_array) > 0:
